References
==========

.. [williams1992] R. J. Williams, "Simple statistical gradient-following
   algorithms for connectionist reinforcement learning," Machine Learning,
   vol. 8, no. 3, pp. 229-256, May 1992.
.. [mikolov2010] T. Mikolov, M. Karafiát, L. Burget, J. Černocký, and S.
   Khudanpur, "Recurrent neural network based language model," presented at
   Interspeech, Makuhari, Japan, 2010.
.. [heafield2011] K. Heafield, "KenLM: Faster and smaller language model
   queries," in Proceedings of the Sixth Workshop on Statistical Machine
   Translation, Edinburgh, Scotland, 2011, pp. 187-197.
.. [bahdanau2015] D. Bahdanau, K. Cho, and Y. Bengio, "Neural machine
   translation by jointly learning to align and translate.," in 3rd
   International Conference on Learning Representations, ICLR 2015, San Diego,
   CA, USA, May 7-9, 2015, Conference Track Proceedings, 2015.
.. [luong2015] T. Luong, H. Pham, and C. D. Manning, "Effective approaches to
   attention-based neural machine translation," in Proceedings of the 2015
   Conference on Empirical Methods in Natural Language Processing, Lisbon,
   Portugal, 2015, pp. 1412-1421.
.. [maddison2016] C. J. Maddison, A. Mnih, and Y. W. Teh, "The Concrete
   distribution: A continuous relaxation of discrete random variables," CoRR,
   vol. abs/1611.00712, 2016.
.. [grathwohl2017] W. Grathwohl, D. Choi, Y. Wu, G. Roeder, and D. K. Duvenaud,
   "Backpropagation through the Void: Optimizing control variates for
   black-box gradient estimation," CoRR, vol. abs/1711.00123, 2017.
.. [vaswani2017] A. Vaswani et al., "Attention is all you beed," in Advances in
   Neural Information Processing Systems 30, I. Guyon, U. V. Luxburg, S.
   Bengio, H. Wallach, R. Fergus, S. Vishwanathan, and R. Garnett, Eds. Curran
   Associates, Inc., 2017, pp. 5998-6008.
.. [tucker2017] G. Tucker, A. Mnih, C. J. Maddison, J. Lawson, and J.
   Sohl-Dickstein, "REBAR: Low-variance, unbiased gradient estimates for
   discrete latent variable models," in Advances in Neural Information
   Processing Systems 30, I. Guyon, U. V. Luxburg, S. Bengio, H. Wallach,
   R. Fergus, S. Vishwanathan, and R. Garnett, Eds. Curran Associates,
   Inc., 2017, pp. 2627-2636.
.. [prabhavalkar2018] R. Prabhavalkar et al., "Minimum Word Error Rate Training
   for Attention-Based Sequence-to-Sequence Models," presented at the IEEE
   International Conference on Acoustics, Speech and Signal Processing
   (ICASSP), 2018, pp. 4839-4843.
.. [sabour2018] S. Sabour, W. Chan, and M. Norouzi, "Optimal Completion
   Distillation for Sequence Learning," CoRR, vol. abs/1810.01398, 2018.
.. [tjandra2018] A. Tjandra, S. Sakti, and S. Nakamura, "Sequence-to-sequence
   ASR optimization via reinforcement learning," presented at the 2018 IEEE
   International Conference on Acoustics, Speech and Signal Processing
   (ICASSP), 2018, pp. 5829-5833.
.. [park2019] D. S. Park et al., "SpecAugment: A simple data augmentation
   method for automatic speech recognition," in Proc. Interspeech, 2019, pp.
   2613–2617, doi: 10.21437/Interspeech.2019-2680.
.. [park2020] D. S. Park et al., "Specaugment on large scale datasets," May
   2020, pp. 6879–6883, doi: 10.1109/ICASSP40776.2020.9053205.

